modern_flutter_ui_kit library

Classes

AppColorScheme
AppTheme
AppTypography
CustomAvatar
A customizable avatar widget with support for different shapes, sizes, and status indicators.
CustomBottomNavBar
A customizable bottom navigation bar widget with support for animations and different styles.
CustomBottomNavBarItem
CustomButton
A customizable button widget with support for different variants and loading state.
CustomCard
A customizable card widget with support for different variants and animations.
CustomDialog
A customizable dialog widget that supports different types and animations.
CustomIconButton
CustomListTile
A customizable list tile widget with support for leading and trailing widgets.
CustomOutlinedButton
CustomTabBar
A customizable tab bar widget with support for animations and different styles.
CustomTextButton
CustomTextField
A customizable text field widget with support for various input types and styles.
DialogExampleScreen
ExampleScreen
ModernButton
A modern, customizable button component.
ModernTheme
The main theme class for the Modern Flutter UI Kit
ModernThemeData
The theme data for the Modern Flutter UI Kit
ThemeProvider

Enums

AvatarShape
The shape of an avatar.
AvatarSize
The size of an avatar.
AvatarStatus
The status indicator of an avatar.
ButtonSize
The size of the button
ButtonVariant
The variant of the button
CardVariant
The visual style variant of a card.
DialogType
The type of dialog to display.